@@ -236,6 +236,9 @@ impl App<'_> {
                 AppEvent::SelectNewerCommit => {
                     self.select_newer_commit();
                 }
+                AppEvent::SelectParentCommit => {
+                    self.select_parent_commit();
+                }
                 AppEvent::CopyToClipboard { name, value } => {
                     self.copy_to_clipboard(name, value);
                 }
@@ -553,6 +556,14 @@ impl App<'_> {
         }
     }
 
+    fn select_parent_commit(&mut self) {
+        if let View::Detail(ref mut view) = self.view {
+            view.select_parent_commit(self.repository);
+        } else if let View::UserCommand(ref mut view) = self.view {
+            view.select_parent_commit(self.repository, self.view_area);
+        }
+    }
+
     fn clear_status_line(&mut self) {
         self.status_line = StatusLine::None;
     }
@@ -583,7 +594,7 @@ impl App<'_> {
     }
 
     fn copy_to_clipboard(&self, name: String, value: String) {
-        match copy_to_clipboard(value) {
+        match copy_to_clipboard(value, &self.core_config.external.clipboard) {
             Ok(_) => {
                 let msg = format!("Copied {name} to clipboard successfully");
                 self.tx.send(AppEvent::NotifySuccess(msg));
