@@ -223,17 +223,31 @@ impl Repository {
 }
 
 fn check_git_repository(path: &Path) -> Result<()> {
+    if !is_inside_work_tree(path) && !is_bare_repository(path) {
+        let msg = "not a git repository (or any of the parent directories)";
+        return Err(msg.into());
+    }
+    Ok(())
+}
+
+fn is_inside_work_tree(path: &Path) -> bool {
     let output = Command::new("git")
         .arg("rev-parse")
         .arg("--is-inside-work-tree")
         .current_dir(path)
         .output()
         .unwrap();
-    if !output.status.success() || output.stdout == b"false\n" {
-        let msg = "not a git repository (or any of the parent directories)";
-        return Err(msg.into());
-    }
-    Ok(())
+    output.status.success() && output.stdout == b"true\n"
+}
+
+fn is_bare_repository(path: &Path) -> bool {
+    let output = Command::new("git")
+        .arg("rev-parse")
+        .arg("--is-bare-repository")
+        .current_dir(path)
+        .output()
+        .unwrap();
+    output.status.success() && output.stdout == b"true\n"
 }
 
 fn load_all_commits(path: &Path, sort: SortCommit, stashes: &[Commit]) -> Vec<Commit> {
@@ -307,6 +321,7 @@ fn load_all_stashes(path: &Path) -> Vec<Commit> {
         .arg("-z") // use NUL as a delimiter
         .current_dir(path)
         .stdout(Stdio::piped())
+        .stderr(Stdio::null())
         .spawn()
         .unwrap();
 
@@ -420,6 +435,7 @@ fn load_refs(path: &Path) -> (RefMap, Head) {
         .arg("--dereference")
         .current_dir(path)
         .stdout(Stdio::piped())
+        .stderr(Stdio::null())
         .spawn()
         .unwrap();
 
@@ -480,6 +496,7 @@ fn load_stashes_as_refs(path: &Path) -> RefMap {
         .arg(format!("--format={format}"))
         .current_dir(path)
         .stdout(Stdio::piped())
+        .stderr(Stdio::null())
         .spawn()
         .unwrap();
 
@@ -558,6 +575,7 @@ fn get_current_branch(path: &Path) -> Option<String> {
         .arg("--show-current")
         .current_dir(path)
         .stdout(Stdio::piped())
+        .stderr(Stdio::null())
         .spawn()
         .unwrap();
 
@@ -592,6 +610,7 @@ pub fn get_diff_summary(path: &Path, commit_hash: &CommitHash) -> Vec<FileChange
         .arg(&commit_hash.0)
         .current_dir(path)
         .stdout(Stdio::piped())
+        .stderr(Stdio::null())
         .spawn()
         .unwrap();
 
@@ -636,6 +655,7 @@ pub fn get_initial_commit_additions(path: &Path, commit_hash: &CommitHash) -> Ve
         .arg(&commit_hash.0)
         .current_dir(path)
         .stdout(Stdio::piped())
+        .stderr(Stdio::null())
         .spawn()
         .unwrap();
 
